pub struct VacantEntry<'a, T> { /* private fields */ }Expand description
A view into a vacant entry in a VecSet.
It is part of the Entry enum.
Implementations
Sourceimpl<'a, T> VacantEntry<'a, T>where
T: Ord,
impl<'a, T> VacantEntry<'a, T>where
T: Ord,
Sourcepub fn index(&self) -> usize
pub fn index(&self) -> usize
Gets the index where the value would be inserted.
Examples
use vecset::VecSet;
let mut set = VecSet::new();
set.insert("a");
set.insert("c");
match set.entry("b") {
vecset::set::Entry::Vacant(e) => {
assert_eq!(e.index(), 1);
}
vecset::set::Entry::Occupied(_) => unreachable!(),
}Sourcepub fn into_value(self) -> T
pub fn into_value(self) -> T
Take ownership of the value.
Examples
use vecset::VecSet;
let mut set = VecSet::new();
match set.entry("a") {
vecset::set::Entry::Vacant(e) => {
assert_eq!(e.into_value(), "a");
}
vecset::set::Entry::Occupied(_) => unreachable!(),
}Sourcepub fn insert(self)
pub fn insert(self)
Sets the value of the entry and returns a reference to it.
Examples
use vecset::VecSet;
let mut set = VecSet::new();
match set.entry("a") {
vecset::set::Entry::Vacant(e) => {
e.insert();
}
vecset::set::Entry::Occupied(_) => unreachable!(),
}
assert!(set.contains(&"a"));Sourcepub fn insert_entry(self) -> OccupiedEntry<'a, T>
pub fn insert_entry(self) -> OccupiedEntry<'a, T>
Sets the value of the entry and returns an OccupiedEntry.
Examples
use vecset::VecSet;
let mut set = VecSet::new();
match set.entry("a") {
vecset::set::Entry::Vacant(e) => {
let occupied = e.insert_entry();
assert_eq!(occupied.get(), &"a");
}
vecset::set::Entry::Occupied(_) => unreachable!(),
}Auto Trait Implementations
impl<'a, T> Freeze for VacantEntry<'a, T>where
T: Freeze,
impl<'a, T> RefUnwindSafe for VacantEntry<'a, T>where
T: RefUnwindSafe,
impl<'a, T> Send for VacantEntry<'a, T>where
T: Send,
impl<'a, T> Sync for VacantEntry<'a, T>where
T: Sync,
impl<'a, T> Unpin for VacantEntry<'a, T>where
T: Unpin,
impl<'a, T> !UnwindSafe for VacantEntry<'a, T>